@@ -4,6 +4,9 @@ import (
 	C "github.com/Dreamacro/clash/constant"
 )
 
+// Implements C.Rule
+var _ C.Rule = (*Match)(nil)
+
 type Match struct {
 	adapter string
 }
@@ -28,6 +31,10 @@ func (f *Match) ShouldResolveIP() bool {
 	return false
 }
 
+func (f *Match) ShouldFindProcess() bool {
+	return false
+}
+
 func NewMatch(adapter string) *Match {
 	return &Match{
 		adapter: adapter,
